SystemOrganization addCategory: #'DuinoBot-Etoys-Graphing'!
SystemOrganization addCategory: #'DuinoBot-Etoys-Spreadsheet'!
SystemOrganization addCategory: #'DuinoBot-Etoys'!
SystemOrganization addCategory: #'DuinoBot-Core-SensorTypes'!
SystemOrganization addCategory: #'DuinoBot-Core'!

Morph subclass: #DBBasicGraphMorph
	instanceVariableNames: 'form pen cartesianBounds points sensor startTime dataColor isGraphing'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DuinoBot-Etoys-Graphing'!

!DBBasicGraphMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 5/11/2011 14:38'!
on: aSensor
	^ (self basicNew setSensor: aSensor) initialize! !

!DBBasicGraphMorph methodsFor: 'accessing' stamp: 'Richo 5/11/2011 20:05'!
addPoint: aPoint
	points size = 10000 ifTrue: [points removeFirst].
	points add: aPoint ! !

!DBBasicGraphMorph methodsFor: 'accessing' stamp: 'Richo 5/6/2011 12:56'!
cartesianBounds
	^ cartesianBounds ! !

!DBBasicGraphMorph methodsFor: 'accessing' stamp: 'Richo 5/6/2011 11:41'!
cartesianBounds: aRectangle 
	cartesianBounds := aRectangle! !

!DBBasicGraphMorph methodsFor: 'calculations' stamp: 'Richo 5/11/2011 14:07'!
cartesianPointToPixel: aPoint in: graphBounds
	^ (self cartesianXToPixel: aPoint x in: graphBounds)
		@ (self cartesianYToPixel: aPoint y in: graphBounds)! !

!DBBasicGraphMorph methodsFor: 'calculations' stamp: 'Richo 5/11/2011 14:08'!
cartesianXToPixel: aNumber in: graphBounds
	^ (graphBounds left + (aNumber - cartesianBounds left * graphBounds width / cartesianBounds width)) rounded! !

!DBBasicGraphMorph methodsFor: 'calculations' stamp: 'Richo 5/11/2011 14:08'!
cartesianYToPixel: aNumber in: graphBounds
	^ (graphBounds bottom - (aNumber - cartesianBounds top * graphBounds height / cartesianBounds height)) rounded! !

!DBBasicGraphMorph methodsFor: 'accessing' stamp: 'Richo 5/11/2011 17:19'!
dataColor
	^ dataColor! !

!DBBasicGraphMorph methodsFor: 'accessing' stamp: 'Richo 5/11/2011 17:19'!
dataColor: aColor
	dataColor := aColor! !

!DBBasicGraphMorph methodsFor: 'drawing' stamp: 'Richo 5/11/2011 17:19'!
drawDataOn: aCanvas in: aRectangle
	| pointsToDraw |
	aCanvas
		frameRectangle: aRectangle color: Color gray muchLighter;
		line: aRectangle topLeft to: aRectangle bottomLeft color: Color gray;
		line: aRectangle bottomLeft - (0@1) to: aRectangle bottomRight - (0@1) color: Color gray.
	pointsToDraw := (points
				select: [:p | p x between: cartesianBounds left and: cartesianBounds right])
				asSortedCollection: [:a :b | a x < b x].
	pointsToDraw isEmpty
		ifTrue: [^ self].
	pointsToDraw
		withIndexDo: [:point :index |
			index = 1 ifFalse: [| from to |
				from := self cartesianPointToPixel: (pointsToDraw at: index - 1) in: aRectangle.
				to := self cartesianPointToPixel: point in: aRectangle.
				aCanvas line: from to: to color: dataColor
			]
		].! !

!DBBasicGraphMorph methodsFor: 'drawing' stamp: 'Richo 5/11/2011 19:18'!
drawLabelsOn: aCanvas
	"REMEMBER: It should return the graph bounds"
	| font yMaxLabelWidth yMinLabelWidth xMaxLabelWidth graphBounds allLabelsHeight xMinLabelWidth |
	font := TextStyle defaultFont.
	yMaxLabelWidth := font widthOfString: self yMaxLabel.
	yMinLabelWidth := font widthOfString: self yMinLabel.
	xMaxLabelWidth := font widthOfString: self xMaxLabel.
	xMinLabelWidth := font widthOfString: self xMinLabel.
	allLabelsHeight := font height.
	graphBounds := Rectangle 
		origin: bounds topLeft 
			+ ({yMaxLabelWidth. yMinLabelWidth. xMinLabelWidth / 2} max rounded @ (allLabelsHeight / 2) rounded) 
			+ (5 @ 0)
		corner: bounds bottomRight 
			- ((xMaxLabelWidth / 2) rounded @ allLabelsHeight)
			- (0 @ 5).
	aCanvas 
		drawString: self yMaxLabel
		at: graphBounds topLeft - (yMaxLabelWidth @ (allLabelsHeight / 2) rounded) - (5 @ 0);
		drawString: self yMinLabel
		at: graphBounds bottomLeft - (yMinLabelWidth @ (allLabelsHeight / 2) rounded) - (5 @ 0);
		drawString: self xMinLabel
		at: graphBounds bottomLeft - ((xMinLabelWidth / 2) rounded @ 0) + (0 @ 5);
		drawString: self xMaxLabel
		at: graphBounds bottomRight - ((xMaxLabelWidth / 2) rounded @ 0) + (0 @ 5).
	^ graphBounds! !

!DBBasicGraphMorph methodsFor: 'drawing' stamp: 'Richo 5/11/2011 17:16'!
drawOn: aCanvas 
	"aCanvas translucentImage: form at: bounds topLeft."
	| graphBounds |
	super drawOn: aCanvas.
	graphBounds := self drawLabelsOn: aCanvas.
	self drawDataOn: aCanvas in: graphBounds.
! !

!DBBasicGraphMorph methodsFor: 'accessing' stamp: 'Richo 5/6/2011 10:58'!
extent: newExtent
	form := Form extent: newExtent depth: 32.
	pen := Pen newOnForm: form.
	super extent: newExtent
! !

!DBBasicGraphMorph methodsFor: 'initialization' stamp: 'Richo 5/11/2011 19:14'!
initialize
	super initialize.
	self extent: 800@200; color: Color transparent.
	points := OrderedCollection new.
	cartesianBounds := (0 @ sensor type minVal corner: 2000 @ sensor type maxVal).
	startTime := Time millisecondClockValue.
	dataColor := Color black.
	isGraphing := false.! !

!DBBasicGraphMorph methodsFor: 'accessing' stamp: 'Richo 5/11/2011 20:09'!
isGraphing
	^ isGraphing ! !

!DBBasicGraphMorph methodsFor: 'stepping' stamp: 'Richo 5/6/2011 11:57'!
move: aPoint 
	cartesianBounds := cartesianBounds translateBy: aPoint.
! !

!DBBasicGraphMorph methodsFor: 'as yet unclassified' stamp: 'Richo 5/11/2011 20:06'!
scrollTo: n
	| intervals selectedInterval |
	isGraphing ifTrue: [^ 1].
	intervals := OrderedCollection new.
	points first x to: points last x - 2000 by: 100 do: [:each |
		intervals add: {each. each + 2000}
		].
	selectedInterval := intervals at: intervals size - 1 * n + 1.
	cartesianBounds := 
(selectedInterval first  @ sensor type minVal corner: selectedInterval second @ sensor type maxVal).
	self changed.
	n! !

!DBBasicGraphMorph methodsFor: 'private' stamp: 'Richo 5/11/2011 14:38'!
setSensor: aDLSensor
	sensor := aDLSensor ! !

!DBBasicGraphMorph methodsFor: 'stepping' stamp: 'Richo 5/11/2011 19:10'!
startGraphing
	isGraphing := true.
	points := OrderedCollection new.
	cartesianBounds := (0 @ sensor type minVal corner: 2000 @ sensor type maxVal).
	startTime := Time millisecondClockValue.	
	self startStepping! !

!DBBasicGraphMorph methodsFor: 'stepping' stamp: 'Richo 5/11/2011 17:51'!
step
	| now |
	isGraphing ifFalse: [^ self].
	now := Time millisecondClockValue - startTime.
	self cartesianBounds: (self cartesianBounds left @ sensor type minVal corner: self cartesianBounds right @ sensor type maxVal);
		 addPoint: now @ sensor value.
	now > self cartesianBounds right
		ifTrue: [self move: 100 @ 0].
	self changed! !

!DBBasicGraphMorph methodsFor: 'stepping' stamp: 'Richo 5/6/2011 10:57'!
stepTime
^ 1! !

!DBBasicGraphMorph methodsFor: 'stepping' stamp: 'Richo 5/11/2011 19:05'!
stopGraphing
	isGraphing := false.
	self stopStepping! !

!DBBasicGraphMorph methodsFor: 'accessing' stamp: 'Richo 5/11/2011 17:10'!
xMaxLabel
	^ (self cartesianBounds right / 1000.0) printShowingDecimalPlaces: 2! !

!DBBasicGraphMorph methodsFor: 'accessing' stamp: 'Richo 5/11/2011 17:10'!
xMinLabel
	^ (self cartesianBounds left / 1000.0) printShowingDecimalPlaces: 2! !

!DBBasicGraphMorph methodsFor: 'accessing' stamp: 'Richo 5/11/2011 17:04'!
yMaxLabel
	^ sensor type maxVal asString! !

!DBBasicGraphMorph methodsFor: 'accessing' stamp: 'Richo 5/11/2011 17:04'!
yMinLabel
	^ sensor type minVal asString! !

Morph subclass: #DBGraphMorph
	instanceVariableNames: 'basicGraph slider'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DuinoBot-Etoys-Graphing'!

!DBGraphMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 5/11/2011 17:43'!
on: aDLSensor
	^ self basicNew initializeWith: aDLSensor! !

!DBGraphMorph methodsFor: 'initialize-release' stamp: 'Richo 5/11/2011 17:48'!
button: label color: aColor
	^ SimpleButtonMorph new
		label: label;
		borderColor: aColor;
		color: (aColor lighter alpha: 0.5).! !

!DBGraphMorph methodsFor: 'accessing' stamp: 'Richo 5/11/2011 20:32'!
extent: aPoint
	| newExtent |
	newExtent := (aPoint x max: self minimumExtent x) @ (aPoint y max: self minimumExtent y).
	^ super extent: newExtent! !

!DBGraphMorph methodsFor: 'initialize-release' stamp: 'Richo 5/11/2011 19:03'!
inARow: anArray
	^ (AlignmentMorph inARow: anArray) 
		borderWidth: 0;
		extent: 1@1;
		layoutInset: 0;
		cellInset: 5;
		vResizing: #shrinkWrap;
		hResizing: #spaceFill;
		wrapCentering: #center;
		cellPositioning: #center.! !

!DBGraphMorph methodsFor: 'initialize-release' stamp: 'Richo 5/11/2011 20:19'!
initialize
	super initialize.
	self layoutPolicy: TableLayout new;
		rubberBandCells: true;
		listDirection: #topToBottom;
		vResizing: #rigid;
		hResizing: #rigid;
		extent: 800@300;
		layoutInset: 5;
		cellInset: 10;
		borderWidth: 1;
		wrapCentering: #center;
		cellPositioning: #leftCenter;
		color: Color white;
		borderColor: Color gray! !

!DBGraphMorph methodsFor: 'initialize-release' stamp: 'Richo 6/10/2011 11:15'!
initializeWith: aDLSensor
	self initialize.
	self addMorphBack: ((basicGraph := DBBasicGraphMorph on: aDLSensor) 
								hResizing: #spaceFill; vResizing: #spaceFill);
		addMorphBack: (self inARow: {
			(self button: 'Iniciar' color: Color green)
				target: basicGraph; actionSelector: #startGraphing.
			(self button: 'Detener' color: Color red)
				target: basicGraph; actionSelector: #stopGraphing.
			(slider := self newSliderFrom: 0 to: 1) 
				setScaledValue: 1; 
				hResizing: #spaceFill; 
				actionSelector: #value:; 
				target: [:sliderValue | basicGraph scrollTo: sliderValue]
			})! !

!DBGraphMorph methodsFor: 'accessing' stamp: 'Richo 5/11/2011 20:30'!
minimumExtent
	^ 250@150! !

!DBGraphMorph methodsFor: 'initialize-release' stamp: 'Richo 5/11/2011 19:25'!
newSliderFrom: minVal to: maxVal 
	^ SimpleSliderMorph new minVal: minVal;
		 maxVal: maxVal;
		 color: Color gray muchLighter;
		 sliderColor: Color blue muchDarker;
		 extent: 200 @ 15! !

!DBGraphMorph methodsFor: 'stepping' stamp: 'Richo 5/11/2011 20:08'!
step
	basicGraph isGraphing ifTrue: [slider setScaledValue: 1]! !

!DBGraphMorph methodsFor: 'stepping' stamp: 'Richo 5/11/2011 20:02'!
stepTime
	^ 200! !

Morph subclass: #DBSpreadsheetMorph
	instanceVariableNames: 'time sensor fileName spreadsheet state index'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DuinoBot-Etoys-Spreadsheet'!

!DBSpreadsheetMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 5/4/2011 13:41'!
new
	self shouldNotImplement! !

!DBSpreadsheetMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 5/4/2011 13:41'!
on: aDLSensor
	^ (self basicNew setSensor: aDLSensor) initialize! !

!DBSpreadsheetMorph methodsFor: 'building' stamp: 'Richo 5/6/2011 15:51'!
button: label color: aColor
	^ SimpleButtonMorph new
		label: label;
		borderColor: aColor;
		color: (aColor lighter alpha: 0.5).! !

!DBSpreadsheetMorph methodsFor: 'initialize-release' stamp: 'Richo 5/4/2011 15:34'!
delete
	self stopStepping.
	super delete! !

!DBSpreadsheetMorph methodsFor: 'accessing' stamp: 'Richo 5/4/2011 16:16'!
fileName
	^ fileName contents asString! !

!DBSpreadsheetMorph methodsFor: 'building' stamp: 'Richo 5/4/2011 13:31'!
inAColumn: anArray
	^ (AlignmentMorph inAColumn: anArray)
		borderWidth: 0;
		extent: 1@1;
		layoutInset: 0;
		cellInset: 0;
		vResizing: #shrinkWrap;
		hResizing: #spaceFill;
		wrapCentering: #center;
		cellPositioning: #leftCenter.! !

!DBSpreadsheetMorph methodsFor: 'building' stamp: 'Richo 5/4/2011 13:31'!
inARow: anArray
	^ (AlignmentMorph inARow: anArray) 
		borderWidth: 0;
		extent: 1@1;
		layoutInset: 0;
		cellInset: 0;
		vResizing: #shrinkWrap;
		hResizing: #spaceFill;
		wrapCentering: #center;
		cellPositioning: #center.! !

!DBSpreadsheetMorph methodsFor: 'initialize-release' stamp: 'Richo 5/6/2011 15:51'!
initialize
	super initialize.
	self layoutPolicy: TableLayout new;
		rubberBandCells: true;
		listDirection: #topToBottom;
		extent: 1@1;
		vResizing: #shrinkWrap;
		hResizing: #shrinkWrap;
		color: (Color r: 0.645 g: 0.71 b: 1.0);
		cornerStyle: #rounded;
		borderColor: #raised;
		layoutInset: 5;
		cellInset: 10.
	time := 0.
	state := #stopped.
	self initializeSubmorphs.! !

!DBSpreadsheetMorph methodsFor: 'initialize-release' stamp: 'Richo 5/4/2011 16:10'!
initializeSubmorphs
	self addMorphBack: ((self inAColumn: {
			self inARow: {
				self spacer.
				self text: sensor type xAxisLabel.
				self text: sensor type yAxisLabel.
				self spacer.
				}.
			spreadsheet := SpreadsheetMorph rows: self maxRows columns: 2})
			cellPositioning: #center).
	self addMorphBack: (self inAColumn: {
			'Nombre del archivo: ' asMorph.
			fileName := (self text: 'datos.csv')
				wrapFlag: false;
				borderWidth: 1;
				backgroundColor: (Color white alpha: 0.8);
				hResizing: #spaceFill.
			}).
	self addMorphBack: ((self inARow: {
			(self button: 'Iniciar' color: Color green)
				target: self; actionSelector: #startStepping.
			(self button: 'Pausar' color: Color yellow)
				target: self; actionSelector: #pauseStepping.
			(self button: 'Detener' color: Color red)
				target: self; actionSelector: #stopStepping.
			})
			cellInset: 5;
			cellPositioning: #leftCenter)
! !

!DBSpreadsheetMorph methodsFor: 'stepping' stamp: 'Richo 5/4/2011 15:50'!
isPaused
	^ state == #paused! !

!DBSpreadsheetMorph methodsFor: 'stepping' stamp: 'Richo 5/4/2011 15:15'!
isRunning
	^ state == #running! !

!DBSpreadsheetMorph methodsFor: 'stepping' stamp: 'Richo 5/4/2011 15:15'!
isStopped
	^ state == #stopped! !

!DBSpreadsheetMorph methodsFor: 'accessing' stamp: 'Richo 5/4/2011 16:13'!
maxRows
	^ 20! !

!DBSpreadsheetMorph methodsFor: 'stepping' stamp: 'Richo 5/4/2011 15:16'!
pauseStepping
	state := #paused.
	super stopStepping! !

!DBSpreadsheetMorph methodsFor: 'printing' stamp: 'Richo 5/4/2011 15:16'!
print: aNumber
	^ (aNumber printShowingDecimalPlaces: 2) copyReplaceAll: '.' with: ','! !

!DBSpreadsheetMorph methodsFor: 'private' stamp: 'Richo 5/4/2011 13:50'!
setSensor: aDLSensor 
	sensor := aDLSensor ! !

!DBSpreadsheetMorph methodsFor: 'building' stamp: 'Richo 5/4/2011 13:31'!
spacer
	^ AlignmentMorph newVariableTransparentSpacer.! !

!DBSpreadsheetMorph methodsFor: 'stepping' stamp: 'Richo 5/4/2011 16:16'!
startStepping
	self isStopped
		ifTrue: [
		time := Time millisecondClockValue.
		[(FileStream forceNewFileNamed: self fileName do: [:file |
			file nextPutAll: sensor type xAxisLabel;
				nextPut: $;;
				nextPutAll: sensor type yAxisLabel;
				cr])] on: Error do: [].
		index := 1.
		spreadsheet clearTable; setAppend].
	state := #running.
	super startStepping! !

!DBSpreadsheetMorph methodsFor: 'stepping' stamp: 'Richo 5/4/2011 16:16'!
step
	| |
	self isRunning ifFalse: [^ self].
	spreadsheet 
		cellValueAt: index @ 1 put: (self print: (Time millisecondClockValue - time) / 1000);
		cellValueAt: index @ 2 put: (self print: sensor value).
	index = self maxRows
		ifTrue: [
			spreadsheet 
				saveCSVFile: self fileName separator: $;;
				clearTable
			].
	index := (index \\ self maxRows) + 1! !

!DBSpreadsheetMorph methodsFor: 'stepping' stamp: 'Richo 5/4/2011 15:56'!
stepTime
	^ 1! !

!DBSpreadsheetMorph methodsFor: 'stepping' stamp: 'Richo 5/4/2011 16:17'!
stopStepping
	self isStopped ifTrue: [^ self].
	state := #stopped.
	spreadsheet
		saveCSVFile: self fileName
		separator: $;.
	super stopStepping! !

!DBSpreadsheetMorph methodsFor: 'building' stamp: 'Richo 5/4/2011 13:31'!
text: aString
	^ UserText new
		contents: aString;
		centered;
		autoFit: false;
		setExtentFromHalo: 100@23;
		layoutChanged! !

Morph subclass: #DataLoggerMorph
	instanceVariableNames: 'portName sensorTypes board'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DuinoBot-Etoys'!

DataLoggerMorph class
	instanceVariableNames: 'form lastPortName'!

DataLoggerMorph class
	instanceVariableNames: 'form lastPortName'!

!DataLoggerMorph class methodsFor: 'viewer categories' stamp: 'Richo 6/10/2011 18:46'!
additionsToViewerCategories
^ #(
(#'adquisidor - conexin' (
#(command conectar 'Conecta este dispositivo' )
#(command desconectar 'Desconecta este dispositivo' )
#(slot estaConectado 'Muestra si el dispositivo est conectado' Boolean readOnly Player getEstaConectado Player unused )
#(slot #'nombre del puerto' 'Nombre del puerto en el que el dispositivo est conectado' DBPort readWrite Player getNombreDelPuerto Player setNombreDelPuerto: )
))

(#'adquisidor - sensores' (
#(slot #'sensor 0' 'Muestra el valor de este sensor' Number readOnly Player getSensor0 Player unused )
#(slot #'sensor 1' 'Muestra el valor de este sensor' Number readOnly Player getSensor1 Player unused )
#(slot #'sensor 2' 'Muestra el valor de este sensor' Number readOnly Player getSensor2 Player unused )
#(slot #'sensor 3' 'Muestra el valor de este sensor' Number readOnly Player getSensor3 Player unused )
#(slot #'sensor 4' 'Muestra el valor de este sensor' Number readOnly Player getSensor4 Player unused )
#(slot #'sensor 0 - tipo' 'Muestra el tipo de este sensor' DBSensorType readWrite Player getSensor0Tipo Player setSensor0Tipo: )
#(slot #'sensor 1 - tipo' 'Muestra el tipo de este sensor' DBSensorType readWrite Player getSensor1Tipo Player setSensor1Tipo: )
#(slot #'sensor 2 - tipo' 'Muestra el tipo de este sensor' DBSensorType readWrite Player getSensor2Tipo Player setSensor2Tipo: )
#(slot #'sensor 3 - tipo' 'Muestra el tipo de este sensor' DBSensorType readWrite Player getSensor3Tipo Player setSensor3Tipo: )
#(slot #'sensor 4 - tipo' 'Muestra el tipo de este sensor' DBSensorType readWrite Player getSensor4Tipo Player setSensor4Tipo: )

))
)! !

!DataLoggerMorph class methodsFor: 'viewer categories' stamp: 'Richo 6/10/2011 18:40'!
defaultNameStemForInstances
	^ 'Adquisidor'! !

!DataLoggerMorph class methodsFor: 'accessing' stamp: 'Richo 6/10/2011 18:40'!
descriptionForPartsBin
	"Answer a description for use in parts bins"
	^ self
		partName: 'Adquisidor' translatedNoop
		categories: {'Electronics' translatedNoop}
		documentation: 'Un objeto que te permite adquirir informacin del mundo fsico' translatedNoop! !

!DataLoggerMorph class methodsFor: 'form' stamp: 'Richo 6/10/2011 16:12'!
form
"
	form := nil.
"
^ form ifNil: [self initializeForm]! !

!DataLoggerMorph class methodsFor: 'form' stamp: 'Richo 6/10/2011 16:12'!
initializeForm
^ form := PEUtilities formFromEncodedPNG: 'iVBORw0KGgoAAAANSUhEUgAAAQcAAAEuCAYAAACDCNdZAAAABHNCSVQFBQUBSsjp7wAAmZdJ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'! !

!DataLoggerMorph class methodsFor: 'accessing' stamp: 'Richo 6/10/2011 16:12'!
lastPortName
^lastPortName! !

!DataLoggerMorph class methodsFor: 'accessing' stamp: 'Richo 6/10/2011 16:12'!
lastPortName: aSymbol
lastPortName := aSymbol! !

!DataLoggerMorph methodsFor: 'viewer category filter' stamp: 'Richo 6/10/2011 16:12'!
categoriesForViewer
	^self validCategories , #(scripting)! !

!DataLoggerMorph methodsFor: 'event handling' stamp: 'Richo 6/10/2011 16:12'!
chooseSensorTypeFor: sensor
	| newType typesToChoose |
	typesToChoose := sensorTypes keys asArray.
	newType := sensorTypes at: (UIManager default chooseFrom: typesToChoose values: typesToChoose title: 'Tipos:') ifAbsent: [^ self].
	sensor type: newType! !

!DataLoggerMorph methodsFor: 'connection' stamp: 'Richo 6/10/2011 16:12'!
connect
	[board connectOnPort: portName]
			on: Error
			do: [:err | self inform: err description]! !

!DataLoggerMorph methodsFor: 'initialize-release' stamp: 'Richo 6/10/2011 16:12'!
delete
self isConnected ifTrue: [self disconnect].
super delete.! !

!DataLoggerMorph methodsFor: 'connection' stamp: 'Richo 6/10/2011 16:12'!
disconnect
	self isConnected ifFalse: [^ self].
	[board m0: 0; m1: 0] on: Error do: [].
	board disconnect! !

!DataLoggerMorph methodsFor: 'drawing' stamp: 'Richo 6/10/2011 16:12'!
drawOn: aCanvas
aCanvas translucentImage: self class form at: self bounds topLeft! !

!DataLoggerMorph methodsFor: 'initialize-release' stamp: 'Richo 6/10/2011 16:12'!
initialize
	super initialize.
	self extent: self class form extent.
	board := DuinoBot new.
	sensorTypes := Array new: 5 withAll: #raw.
	self initializePortName;
		initializeSensorTypes;
		initializeSubmorphs! !

!DataLoggerMorph methodsFor: 'initialize-release' stamp: 'Richo 6/10/2011 16:12'!
initializePortName
	| availablePorts block |
	block := [PESerialPortList availableSerialPorts asSet asSortedCollection].
	availablePorts := block value.
	Vocabulary addStandardVocabulary: (PluggableListType new vocabularyName: #DBPort;
			 block: [block value, #(#'other...' )]).
	(availablePorts includes: self class lastPortName)
		ifFalse: [self class lastPortName: availablePorts last].
	portName := self class lastPortName ! !

!DataLoggerMorph methodsFor: 'initialize-release' stamp: 'Richo 6/10/2011 16:12'!
initializeSensorTypes
	sensorTypes := Dictionary new.
	DBSensorType withAllSubclassesDo: [:each |
		sensorTypes at: each sensorName asSymbol put: each].
	Vocabulary addStandardVocabulary: (SymbolListType new vocabularyName: #DBSensorType;
			 symbols: sensorTypes keys asArray)
	! !

!DataLoggerMorph methodsFor: 'initialize-release' stamp: 'Richo 6/10/2011 16:12'!
initializeSubmorphs
	#(103 74 45 16 -13)
		doWithIndex: [:y :index | | x morph |
			x := 101.
			morph := Morph new
						extent: 40@30;
						center: self center + (x@y);
						color: Color transparent;
						borderWidth: 2;
						borderColor: Color transparent;
						yourself.
			morph
				on: #mouseUp send: #mouseUp:event:morph: to: self withValue: index - 1;
				on: #mouseEnter send: #value:value: to: [:evt :m | m borderColor: Color red];
				on: #mouseLeave send: #value:value: to: [:evt :m | m borderColor: Color transparent].
			self addMorph: morph.
		]! !

!DataLoggerMorph methodsFor: 'connection' stamp: 'Richo 6/10/2011 16:12'!
isConnected
^board isConnected! !

!DataLoggerMorph methodsFor: 'event handling' stamp: 'Richo 6/10/2011 16:12'!
mouseUp: sensorIndex event: evt morph: aMorph 
	| choice sensor |
	aMorph borderColor: Color red.
	sensor := 	board perform: ('s', sensorIndex asString) asSymbol.
	choice := UIManager default chooseFrom: #('tipo de sensor' 'dame grfico' 'dame planilla' ) title: ''.
	choice caseOf: {
		[1] -> [self chooseSensorTypeFor: sensor].
		[2] -> [self openGraphFor: sensor].
		[3] -> [self openSpreadsheetFor: sensor]}
		 otherwise: [].
	aMorph borderColor: Color transparent! !

!DataLoggerMorph methodsFor: 'viewer category filter' stamp: 'Richo 6/10/2011 16:12'!
newPlayerInstance
^ DuinoBotPlayer newUserInstance! !

!DataLoggerMorph methodsFor: 'event handling' stamp: 'Richo 6/10/2011 16:12'!
openGraphFor: sensor 
	(DBGraphMorph on: sensor) openInHand! !

!DataLoggerMorph methodsFor: 'event handling' stamp: 'Richo 6/10/2011 16:12'!
openSpreadsheetFor: sensor
	(DBSpreadsheetMorph on: sensor) openInHand! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 16:12'!
portName
^ portName ! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 16:12'!
portName: aSymbol 
	self isConnected
		ifTrue: [^ self].
	portName := aSymbol = #'other...'
				ifTrue: [(FillInTheBlank request: 'Port name:' translated) asSymbol]
				ifFalse: [aSymbol].
	self class lastPortName: portName! !

!DataLoggerMorph methodsFor: 'fileOut' stamp: 'Richo 6/10/2011 16:12'!
prepareToBeSaved
"When saving a project be sure to disconnect the board, otherwise we will have a lot of problems"
	super prepareToBeSaved.
	self isConnected ifTrue: [self disconnect]! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 16:12'!
sensor0
	^ board s0 value! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 16:12'!
sensor0Type
	^  board s0 type sensorName! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 16:12'!
sensor0Type: aSymbol
	^  board s0 type: (sensorTypes at: aSymbol)! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 16:12'!
sensor1
	^ board s1 value! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 16:12'!
sensor1Type
	^  board s1 type sensorName! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 16:12'!
sensor1Type: aSymbol
	^  board s1 type: (sensorTypes at: aSymbol)! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 16:12'!
sensor2
	^ board s2 value! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 16:12'!
sensor2Type
	^  board s2 type sensorName! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 16:12'!
sensor2Type: aSymbol
	^  board s2 type: (sensorTypes at: aSymbol)! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 16:12'!
sensor3
	^ board s3 value! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 16:12'!
sensor3Type
	^  board s3 type sensorName! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 16:12'!
sensor3Type: aSymbol
	^  board s3 type: (sensorTypes at: aSymbol)! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 16:12'!
sensor4
	^ board s4 value! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 16:12'!
sensor4Type
	^  board s4 type sensorName! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 16:12'!
sensor4Type: aSymbol
	^  board s4 type: (sensorTypes at: aSymbol)! !

!DataLoggerMorph methodsFor: 'viewer category filter' stamp: 'Richo 6/10/2011 16:12'!
validCategories
"Returns valid categories for the Arduino object"
^(self class additionsToViewerCategories collect: [:each| each first])! !

Morph subclass: #DuinoBotMorph
	instanceVariableNames: 'portName sensorTypes board'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DuinoBot-Etoys'!

DuinoBotMorph class
	instanceVariableNames: 'lastPortName form robotForm'!

DuinoBotMorph class
	instanceVariableNames: 'lastPortName form robotForm'!

!DuinoBotMorph class methodsFor: 'viewer categories' stamp: 'Richo 6/10/2011 16:32'!
additionsToViewerCategories
^ #(
(#'duinobot - conexin' (
#(command conectar 'Conecta este dispositivo' )
#(command desconectar 'Desconecta este dispositivo' )
#(slot estaConectado 'Muestra si el dispositivo est conectado' Boolean readOnly Player getEstaConectado Player unused )
#(slot #'nombre del puerto' 'Nombre del puerto en el que el dispositivo est conectado' DBPort readWrite Player getNombreDelPuerto Player setNombreDelPuerto: )
))

(#'duinobot - motores' (
#(slot #'motor 0' 'Permite cambiar la velocidad del motor' Number readWrite Player getMotor0 Player setMotor0:)
#(slot #'motor 1' 'Permite cambiar la velocidad del motor' Number readWrite Player getMotor1 Player setMotor1:)
))


(#'duinobot - sensores' (
#(slot #'sensor 0' 'Muestra el valor de este sensor' Number readOnly Player getSensor0 Player unused )
#(slot #'sensor 1' 'Muestra el valor de este sensor' Number readOnly Player getSensor1 Player unused )
#(slot #'sensor 2' 'Muestra el valor de este sensor' Number readOnly Player getSensor2 Player unused )
#(slot #'sensor 3' 'Muestra el valor de este sensor' Number readOnly Player getSensor3 Player unused )
#(slot #'sensor 4' 'Muestra el valor de este sensor' Number readOnly Player getSensor4 Player unused )
#(slot #'sensor 5' 'Muestra el valor de este sensor' Number readOnly Player getSensor5 Player unused )
#(slot #'sensor 0 - tipo' 'Muestra el tipo de este sensor' DBSensorType readWrite Player getSensor0Tipo Player setSensor0Tipo: )
#(slot #'sensor 1 - tipo' 'Muestra el tipo de este sensor' DBSensorType readWrite Player getSensor1Tipo Player setSensor1Tipo: )
#(slot #'sensor 2 - tipo' 'Muestra el tipo de este sensor' DBSensorType readWrite Player getSensor2Tipo Player setSensor2Tipo: )
#(slot #'sensor 3 - tipo' 'Muestra el tipo de este sensor' DBSensorType readWrite Player getSensor3Tipo Player setSensor3Tipo: )
#(slot #'sensor 4 - tipo' 'Muestra el tipo de este sensor' DBSensorType readWrite Player getSensor4Tipo Player setSensor4Tipo: )
#(slot #'sensor 5 - tipo' 'Muestra el tipo de este sensor' DBSensorType readWrite Player getSensor5Tipo Player setSensor5Tipo: )
))
)! !

!DuinoBotMorph class methodsFor: 'viewer categories' stamp: 'Richo 6/10/2011 11:15'!
defaultNameStemForInstances
	^ 'DuinoBot'! !

!DuinoBotMorph class methodsFor: 'accessing' stamp: 'Richo 6/10/2011 12:37'!
descriptionForPartsBin
	"Answer a description for use in parts bins"
	^ self
		partName: 'DuinoBot' translatedNoop
		categories: {'Electronics' translatedNoop}
		documentation: 'Una placa que te permite comunicarte con motores y sensores' translatedNoop! !

!DuinoBotMorph class methodsFor: 'form' stamp: 'Richo 4/25/2011 15:26'!
form
"
	form := nil.
"
^ form ifNil: [self initializeForm]! !

!DuinoBotMorph class methodsFor: 'form' stamp: 'Richo 6/10/2011 16:15'!
initializeForm
^ form := PEUtilities formFromEncodedPNG: 'iVBORw0KGgoAAAANSUhEUgAAAY8AAAFYCAYAAACroXBwAAAABHNCSVQFBQUBSsjp7wAAK+hJ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'! !

!DuinoBotMorph class methodsFor: 'accessing' stamp: 'Richo 6/8/2011 18:24'!
lastPortName
^lastPortName! !

!DuinoBotMorph class methodsFor: 'accessing' stamp: 'Richo 4/25/2011 16:08'!
lastPortName: aSymbol
lastPortName := aSymbol! !

!DuinoBotMorph class methodsFor: 'form' stamp: 'Richo 6/14/2011 14:51'!
robotForm
"
	robotForm := nil.
"
	^ robotForm ifNil: [robotForm :=  PEUtilities formFromEncodedPNG: 'iVBORw0KGgoAAAANSUhEUgAAAHoAAACWCAYAAAAR35wdAAAACXBIWXMAAA3XAAAN1wFCKJt4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']! !

!DuinoBotMorph methodsFor: 'viewer category filter' stamp: 'Richo 4/25/2011 16:12'!
categoriesForViewer
	^self validCategories , #(scripting)! !

!DuinoBotMorph methodsFor: 'event handling' stamp: 'Richo 5/4/2011 11:34'!
chooseSensorTypeFor: sensor
	| newType typesToChoose |
	typesToChoose := sensorTypes keys asArray.
	newType := sensorTypes at: (UIManager default chooseFrom: typesToChoose values: typesToChoose title: 'Tipos:') ifAbsent: [^ self].
	sensor type: newType! !

!DuinoBotMorph methodsFor: 'connection' stamp: 'Richo 6/10/2011 11:11'!
connect
	[board connectOnPort: portName]
			on: Error
			do: [:err | self inform: err description]! !

!DuinoBotMorph methodsFor: 'initialize-release' stamp: 'Richo 4/25/2011 16:17'!
delete
self isConnected ifTrue: [self disconnect].
super delete.! !

!DuinoBotMorph methodsFor: 'connection' stamp: 'Richo 6/10/2011 12:52'!
disconnect
	self isConnected ifFalse: [^ self].
	[board m0: 0; m1: 0] on: Error do: [].
	board disconnect! !

!DuinoBotMorph methodsFor: 'drawing' stamp: 'Richo 6/14/2011 14:52'!
drawOn: aCanvas
aCanvas translucentImage: self class form at: self bounds topLeft;
		translucentImage: self class robotForm at: self bounds topLeft + (22@17)! !

!DuinoBotMorph methodsFor: 'initialize-release' stamp: 'Richo 6/10/2011 11:10'!
initialize
	super initialize.
	self extent: self class form extent.
	board := DuinoBot new.
	sensorTypes := Array new: 5 withAll: #raw.
	self initializePortName;
		initializeSensorTypes;
		initializeSubmorphs! !

!DuinoBotMorph methodsFor: 'initialize-release' stamp: 'Richo 6/10/2011 11:28'!
initializePortName
	| availablePorts block |
	block := [PESerialPortList availableSerialPorts asSet asSortedCollection].
	availablePorts := block value.
	Vocabulary addStandardVocabulary: (PluggableListType new vocabularyName: #DBPort;
			 block: [block value, #(#'other...' )]).
	(availablePorts includes: self class lastPortName)
		ifFalse: [self class lastPortName: availablePorts last].
	portName := self class lastPortName ! !

!DuinoBotMorph methodsFor: 'initialize-release' stamp: 'Richo 6/10/2011 11:14'!
initializeSensorTypes
	sensorTypes := Dictionary new.
	DBSensorType withAllSubclassesDo: [:each |
		sensorTypes at: each sensorName asSymbol put: each].
	Vocabulary addStandardVocabulary: (SymbolListType new vocabularyName: #DBSensorType;
			 symbols: sensorTypes keys asArray)
	! !

!DuinoBotMorph methodsFor: 'initialize-release' stamp: 'Richo 6/10/2011 16:39'!
initializeSubmorphs
	"Sensors"
	 {164@293. 197@293. 230@293. 263@293. 296@293. 329@293}
		doWithIndex: [:distToOrigin :index | | x morph |
			morph := Morph new
						extent: 33@44;
						position: self position + distToOrigin;
						color: Color transparent;
						borderWidth: 2;
						borderColor: Color transparent;
						yourself.
			morph
				on: #mouseUp send: #sensorMouseUp:event:morph: to: self withValue: index - 1;
				on: #mouseEnter send: #value:value: to: [:evt :m | m borderColor: Color red];
				on: #mouseLeave send: #value:value: to: [:evt :m | m borderColor: Color transparent].
			self addMorph: morph.
		].
	"Motors"
	{354@227.  354@192}
		doWithIndex: [:distToOrigin :index | | x morph |
			morph := Morph new
						extent: 37@35;
						position: self position + distToOrigin;
						color: Color transparent;
						borderWidth: 2;
						borderColor: Color transparent;
						yourself.
			morph
				on: #mouseUp send: #motorMouseUp:event:morph: to: self withValue: index - 1;
				on: #mouseEnter send: #value:value: to: [:evt :m | m borderColor: Color red];
				on: #mouseLeave send: #value:value: to: [:evt :m | m borderColor: Color transparent].
			self addMorph: morph.
		].! !

!DuinoBotMorph methodsFor: 'connection' stamp: 'Richo 6/10/2011 11:11'!
isConnected
^board isConnected! !

!DuinoBotMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 11:46'!
m0
	^ board m0! !

!DuinoBotMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 11:46'!
m0: aSmallInteger 
	board m0: aSmallInteger ! !

!DuinoBotMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 11:46'!
m1
	^ board m1! !

!DuinoBotMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 11:48'!
m1: aSmallInteger 
	board m1: aSmallInteger ! !

!DuinoBotMorph methodsFor: 'event handling' stamp: 'Richo 6/10/2011 16:42'!
motorMouseUp: motorIndex event: evt morph: aMorph 
	self assuredPlayer tearOffFancyWatcherFor: (#getMotor, motorIndex asString) asSymbol.
	aMorph borderColor: Color transparent! !

!DuinoBotMorph methodsFor: 'viewer category filter' stamp: 'Richo 6/10/2011 11:15'!
newPlayerInstance
^ DuinoBotPlayer newUserInstance! !

!DuinoBotMorph methodsFor: 'event handling' stamp: 'Richo 6/10/2011 11:15'!
openGraphFor: sensor 
	(DBGraphMorph on: sensor) openInHand! !

!DuinoBotMorph methodsFor: 'event handling' stamp: 'Richo 6/10/2011 11:15'!
openSpreadsheetFor: sensor
	(DBSpreadsheetMorph on: sensor) openInHand! !

!DuinoBotMorph methodsFor: 'accessing' stamp: 'Richo 4/25/2011 16:13'!
portName
^ portName ! !

!DuinoBotMorph methodsFor: 'accessing' stamp: 'Richo 4/25/2011 16:13'!
portName: aSymbol 
	self isConnected
		ifTrue: [^ self].
	portName := aSymbol = #'other...'
				ifTrue: [(FillInTheBlank request: 'Port name:' translated) asSymbol]
				ifFalse: [aSymbol].
	self class lastPortName: portName! !

!DuinoBotMorph methodsFor: 'fileOut' stamp: 'Richo 4/25/2011 16:13'!
prepareToBeSaved
"When saving a project be sure to disconnect the board, otherwise we will have a lot of problems"
	super prepareToBeSaved.
	self isConnected ifTrue: [self disconnect]! !

!DuinoBotMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 11:12'!
sensor0
	^ board s0 value! !

!DuinoBotMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 11:11'!
sensor0Type
	^  board s0 type sensorName! !

!DuinoBotMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 11:11'!
sensor0Type: aSymbol
	^  board s0 type: (sensorTypes at: aSymbol)! !

!DuinoBotMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 11:11'!
sensor1
	^ board s1 value! !

!DuinoBotMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 11:11'!
sensor1Type
	^  board s1 type sensorName! !

!DuinoBotMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 11:11'!
sensor1Type: aSymbol
	^  board s1 type: (sensorTypes at: aSymbol)! !

!DuinoBotMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 11:11'!
sensor2
	^ board s2 value! !

!DuinoBotMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 11:11'!
sensor2Type
	^  board s2 type sensorName! !

!DuinoBotMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 11:11'!
sensor2Type: aSymbol
	^  board s2 type: (sensorTypes at: aSymbol)! !

!DuinoBotMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 11:11'!
sensor3
	^ board s3 value! !

!DuinoBotMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 11:11'!
sensor3Type
	^  board s3 type sensorName! !

!DuinoBotMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 11:12'!
sensor3Type: aSymbol
	^  board s3 type: (sensorTypes at: aSymbol)! !

!DuinoBotMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 11:11'!
sensor4
	^ board s4 value! !

!DuinoBotMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 11:11'!
sensor4Type
	^  board s4 type sensorName! !

!DuinoBotMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 11:11'!
sensor4Type: aSymbol
	^  board s4 type: (sensorTypes at: aSymbol)! !

!DuinoBotMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 16:34'!
sensor5
	^ board s5 value! !

!DuinoBotMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 16:34'!
sensor5Type
	^  board s5 type sensorName! !

!DuinoBotMorph methodsFor: 'accessing' stamp: 'Richo 6/10/2011 16:34'!
sensor5Type: aSymbol
	^  board s5 type: (sensorTypes at: aSymbol)! !

!DuinoBotMorph methodsFor: 'event handling' stamp: 'Richo 6/10/2011 16:39'!
sensorMouseUp: sensorIndex event: evt morph: aMorph 
	| choice sensor |
	aMorph borderColor: Color red.
	sensor := 	board perform: ('s', sensorIndex asString) asSymbol.
	choice := UIManager default chooseFrom: #('tipo de sensor' 'dame grfico' 'dame planilla' ) title: ''.
	choice caseOf: {
		[1] -> [self chooseSensorTypeFor: sensor].
		[2] -> [self openGraphFor: sensor].
		[3] -> [self openSpreadsheetFor: sensor]}
		 otherwise: [].
	aMorph borderColor: Color transparent! !

!DuinoBotMorph methodsFor: 'viewer category filter' stamp: 'Richo 4/25/2011 16:12'!
validCategories
"Returns valid categories for the Arduino object"
^(self class additionsToViewerCategories collect: [:each| each first])! !

Object subclass: #DBSensorType
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DuinoBot-Core-SensorTypes'!

DBSensorType subclass: #DBButtonType
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DuinoBot-Core-SensorTypes'!

!DBButtonType class methodsFor: 'as yet unclassified' stamp: 'Richo 5/4/2011 11:18'!
interval
^ 0 to: 1! !

!DBButtonType class methodsFor: 'as yet unclassified' stamp: 'Richo 5/4/2011 11:19'!
scale: aNumber
	^ (aNumber / 1023) rounded! !

!DBButtonType class methodsFor: 'as yet unclassified' stamp: 'Richo 5/4/2011 11:18'!
sensorName
	^#botn! !

!DBSensorType class methodsFor: 'as yet unclassified' stamp: 'Richo 5/4/2011 11:18'!
interval
^ 0 to: 1023! !

!DBSensorType class methodsFor: 'as yet unclassified' stamp: 'Richo 5/4/2011 11:18'!
maxVal
^ self interval max! !

!DBSensorType class methodsFor: 'as yet unclassified' stamp: 'Richo 5/4/2011 11:18'!
minVal
^ self interval min! !

!DBSensorType class methodsFor: 'as yet unclassified' stamp: 'Richo 5/4/2011 11:18'!
scale: aNumber
	^ aNumber! !

!DBSensorType class methodsFor: 'as yet unclassified' stamp: 'Richo 5/4/2011 11:18'!
sensorName
	^ #raw! !

!DBSensorType class methodsFor: 'as yet unclassified' stamp: 'Richo 5/4/2011 11:18'!
xAxisLabel
	^ 'tiempo'! !

!DBSensorType class methodsFor: 'as yet unclassified' stamp: 'Richo 5/4/2011 11:18'!
yAxisLabel
	^ 'valor'! !

Object subclass: #DuinoBot
	instanceVariableNames: 'port steppingProcess sensors motors'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DuinoBot-Core'!

!DuinoBot class methodsFor: 'constants' stamp: 'Richo 6/10/2011 17:01'!
firmware
"Compile with http://www.robotgroup.com.ar/soft/DuinoPack.v0.1/DuinoPack.v0.1.zip"
^ '#include <MotorDC.h>


// Creates an instance of the MotorDC class, specifying
// the pins for Enable, D0 and D1 bits for the H-Bridge:
MotorDC motorDC0(3, 4, 8);
MotorDC motorDC1(22, 20, 21);

////////////////////////////////////////////
void setup() {
  // initialize serial communications at 9600 bps:
  Serial.begin(115200);
//  Screen.showSprite(smile);
}
void loop() {

  if(Serial.available() > 0)
  {
    if(Serial.read()==77 /* $M */) 
    {
      byte motor = Serial.read();
      int newSpeed = Serial.read()-127;
      if(motor==0) { motorDC0.setSpeed(newSpeed); }
      if(motor==1) { motorDC1.setSpeed(newSpeed); }
    }
  }

  Serial.print("S0=");
  Serial.print(analogRead(0));
  Serial.print("; time=");
  Serial.println(millis());
  Serial.print("S1=");
  Serial.print(analogRead(1));
  Serial.print("; time=");
  Serial.println(millis());
  Serial.print("S2=");
  Serial.print(analogRead(2));
  Serial.print("; time=");
  Serial.println(millis());
  Serial.print("S3=");
  Serial.print(analogRead(3));
  Serial.print("; time=");
  Serial.println(millis());
  Serial.print("S4=");
  Serial.print(analogRead(4));
  Serial.print("; time=");
  Serial.println(millis());
  Serial.print("S5=");
  Serial.print(analogRead(5));
  Serial.print("; time=");
  Serial.println(millis());

}
////////////////////////////////////////////'! !

!DuinoBot methodsFor: 'connection' stamp: 'Richo 4/25/2011 15:03'!
connectOnPort: portName
	port := SerialPort new baudRate: 115200.
	port := port
				openPort: (('COM*' match: portName)
						ifTrue: [portName asInteger]
						ifFalse: [portName]).
	self isConnected
		ifTrue: [self startSteppingProcess]! !

!DuinoBot methodsFor: 'connection' stamp: 'Richo 4/25/2011 15:43'!
disconnect
	self isConnected
		ifTrue: [self stopSteppingProcess.
			port close.
			port := nil.
			self initializeSensors]! !

!DuinoBot methodsFor: 'initialize-release' stamp: 'Richo 6/10/2011 11:16'!
initialize
	super initialize.
	self initializeSensors; initializeMotors! !

!DuinoBot methodsFor: 'initialize-release' stamp: 'Richo 6/10/2011 11:26'!
initializeMotors
	motors := #(0 0)! !

!DuinoBot methodsFor: 'initialize-release' stamp: 'Richo 6/10/2011 11:22'!
initializeSensors
	sensors := (1 to: 6) collect: [:ign | DuinoBotSensor new]! !

!DuinoBot methodsFor: 'connection' stamp: 'Richo 4/25/2011 15:02'!
isConnected
	^ port notNil! !

!DuinoBot methodsFor: 'accessing' stamp: 'Richo 6/10/2011 11:24'!
m0
	^ motors at: 1! !

!DuinoBot methodsFor: 'accessing' stamp: 'Richo 6/10/2011 11:47'!
m0: power
	| scale |
	self isConnected ifFalse: [^ self].
	motors at: 1 put: (power min: 100 max: -100).
	"scale:
	-100 ----- 0
	0 	   ----- 127
	100  ----- 255"
	scale := [:x | (1.275 * x + 127.5) rounded].
	port nextPutAll: {77. 0. scale value: self m0} asByteArray! !

!DuinoBot methodsFor: 'accessing' stamp: 'Richo 6/10/2011 11:19'!
m1
	^ motors at: 2! !

!DuinoBot methodsFor: 'accessing' stamp: 'Richo 6/10/2011 11:48'!
m1: power
	| scale |
	self isConnected ifFalse: [^ self].
	motors at: 2 put: (power min: 100 max: -100).
	"scale:
	-100 ----- 0
	0 	   ----- 127
	100  ----- 255"
	scale := [:x | (1.275 * x + 127.5) rounded].
	port nextPutAll: {77. 1. scale value: self m1} asByteArray! !

!DuinoBot methodsFor: 'stepping' stamp: 'Richo 6/8/2011 18:09'!
processInput
	| data |
	data := port readString.
	(data subStrings: {Character lf})
		do: [:line | 
			((line withBlanksTrimmed beginsWith: 'S') and: [line includes: $;])
				ifTrue: [(sensors at: line second asString asNumber + 1)
						value: ((line upTo: $;) allButFirst: 3) asInteger]]! !

!DuinoBot methodsFor: 'accessing' stamp: 'Richo 4/25/2011 15:42'!
s0
	^ sensors at: 1! !

!DuinoBot methodsFor: 'accessing' stamp: 'Richo 4/25/2011 15:42'!
s1
	^ sensors at: 2! !

!DuinoBot methodsFor: 'accessing' stamp: 'Richo 4/25/2011 15:43'!
s2
	^ sensors at: 3! !

!DuinoBot methodsFor: 'accessing' stamp: 'Richo 4/25/2011 15:43'!
s3
	^ sensors at: 4! !

!DuinoBot methodsFor: 'accessing' stamp: 'Richo 4/25/2011 15:43'!
s4
	^ sensors at: 5! !

!DuinoBot methodsFor: 'accessing' stamp: 'Richo 6/10/2011 11:22'!
s5
	^ sensors at: 6! !

!DuinoBot methodsFor: 'stepping' stamp: 'Richo 6/6/2011 15:57'!
startSteppingProcess
	steppingProcess notNil
		ifTrue: [^ self].
	steppingProcess := [[
			self step.
			(Delay forMilliseconds: self stepTime) wait] repeat]
				forkNamed: self asString ! !

!DuinoBot methodsFor: 'stepping' stamp: 'Richo 6/6/2011 15:57'!
step
	[self processInput]
			on: Error
			do: [:err | Transcript show: self asString , ': ' , err description; cr]! !

!DuinoBot methodsFor: 'stepping' stamp: 'Richo 6/10/2011 12:22'!
stepTime
	^ 10! !

!DuinoBot methodsFor: 'stepping' stamp: 'Richo 4/25/2011 15:34'!
stopSteppingProcess
	steppingProcess isNil
		ifTrue: [^ self].
	steppingProcess terminate.
	steppingProcess := nil! !

Object subclass: #DuinoBotSensor
	instanceVariableNames: 'type value'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DuinoBot-Core'!

!DuinoBotSensor methodsFor: 'as yet unclassified' stamp: 'Richo 6/10/2011 11:13'!
initialize
	super initialize.
	type := DBSensorType.
"	Storing historic values wasn't necessary so I removed the old implementation. I kept it here as a comment in case someone wants to use it. 	
	See #value: and #value

	values := OrderedCollection new
					add: -1;
					yourself"
	value := -1! !

!DuinoBotSensor methodsFor: 'accessing' stamp: 'Richo 5/4/2011 11:21'!
type
	^ type! !

!DuinoBotSensor methodsFor: 'accessing' stamp: 'Richo 5/4/2011 11:22'!
type: aDLSensorType
	type := aDLSensorType 
	! !

!DuinoBotSensor methodsFor: 'accessing' stamp: 'Richo 5/11/2011 20:14'!
value
	"Storing historic values wasn't necessary so I removed the old implementation. I kept it here as a comment in case someone wants to use it. 
	See #value: and #initialize

	^ values last"
	^ value! !

!DuinoBotSensor methodsFor: 'accessing' stamp: 'Richo 5/24/2011 16:57'!
value: aNumber
	"Storing historic values wasn't necessary so I removed the old implementation. I kept it here as a comment in case someone wants to use it.
	See #value and #initialize

	| newValue |
	values add: (newValue := type scale: aNumber)"
	value := (type scale: aNumber)! !

Player subclass: #DuinoBotPlayer
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DuinoBot-Etoys'!

!DuinoBotPlayer class methodsFor: 'as yet unclassified' stamp: 'Richo 4/25/2011 16:44'!
isUniClass
	^ self ~~ self officialClass! !

!DuinoBotPlayer class methodsFor: 'as yet unclassified' stamp: 'Richo 6/10/2011 11:15'!
officialClass
	^ DuinoBotPlayer! !

!DuinoBotPlayer class methodsFor: 'as yet unclassified' stamp: 'Richo 4/25/2011 16:44'!
wantsChangeSetLogging
	"Log changes for Player itself, but not for automatically-created subclasses like Player1, Player2, but *do* log it for uniclasses that have been manually renamed."

	^ (self == self officialClass or:
		[(self name beginsWith: self officialClass asString) not]) or:
			[Preferences universalTiles]! !

!DuinoBotPlayer methodsFor: 'connection' stamp: 'Richo 4/25/2011 17:15'!
conectar
^ self costume renderedMorph connect! !

!DuinoBotPlayer methodsFor: 'connection' stamp: 'Richo 4/25/2011 17:15'!
desconectar
^ self costume renderedMorph disconnect! !

!DuinoBotPlayer methodsFor: 'connection' stamp: 'Richo 4/25/2011 17:15'!
getEstaConectado
^ self costume renderedMorph isConnected! !

!DuinoBotPlayer methodsFor: 'motors' stamp: 'Richo 6/10/2011 11:44'!
getMotor0
	^ self costume renderedMorph m0! !

!DuinoBotPlayer methodsFor: 'motors' stamp: 'Richo 6/10/2011 11:44'!
getMotor1
	^ self costume renderedMorph m1! !

!DuinoBotPlayer methodsFor: 'connection' stamp: 'Richo 4/25/2011 17:15'!
getNombreDelPuerto
 ^ self costume renderedMorph portName! !

!DuinoBotPlayer methodsFor: 'sensor values' stamp: 'Richo 4/25/2011 16:14'!
getSensor0
	^ self costume renderedMorph sensor0! !

!DuinoBotPlayer methodsFor: 'sensor types' stamp: 'Richo 4/25/2011 17:15'!
getSensor0Tipo
	^ self costume renderedMorph sensor0Type! !

!DuinoBotPlayer methodsFor: 'sensor values' stamp: 'Richo 4/25/2011 16:14'!
getSensor1
	^ self costume renderedMorph sensor1! !

!DuinoBotPlayer methodsFor: 'sensor types' stamp: 'Richo 4/25/2011 17:15'!
getSensor1Tipo
	^ self costume renderedMorph sensor1Type! !

!DuinoBotPlayer methodsFor: 'sensor values' stamp: 'Richo 4/25/2011 16:14'!
getSensor2
	^ self costume renderedMorph sensor2! !

!DuinoBotPlayer methodsFor: 'sensor types' stamp: 'Richo 4/25/2011 17:15'!
getSensor2Tipo
	^ self costume renderedMorph sensor2Type! !

!DuinoBotPlayer methodsFor: 'sensor values' stamp: 'Richo 4/25/2011 16:15'!
getSensor3
	^ self costume renderedMorph sensor3! !

!DuinoBotPlayer methodsFor: 'sensor types' stamp: 'Richo 4/25/2011 17:15'!
getSensor3Tipo
	^ self costume renderedMorph sensor3Type! !

!DuinoBotPlayer methodsFor: 'sensor values' stamp: 'Richo 4/25/2011 16:15'!
getSensor4
	^ self costume renderedMorph sensor4! !

!DuinoBotPlayer methodsFor: 'sensor types' stamp: 'Richo 4/25/2011 17:16'!
getSensor4Tipo
	^ self costume renderedMorph sensor4Type! !

!DuinoBotPlayer methodsFor: 'sensor values' stamp: 'Richo 6/10/2011 16:33'!
getSensor5
	^ self costume renderedMorph sensor5! !

!DuinoBotPlayer methodsFor: 'sensor types' stamp: 'Richo 6/10/2011 16:34'!
getSensor5Tipo
	^ self costume renderedMorph sensor5Type! !

!DuinoBotPlayer methodsFor: 'motors' stamp: 'Richo 6/10/2011 11:44'!
setMotor0: aNumber
	self costume renderedMorph m0: aNumber! !

!DuinoBotPlayer methodsFor: 'motors' stamp: 'Richo 6/10/2011 11:44'!
setMotor1: aNumber
	self costume renderedMorph m1: aNumber! !

!DuinoBotPlayer methodsFor: 'connection' stamp: 'Richo 4/25/2011 17:15'!
setNombreDelPuerto: aSymbol 
	^ self costume renderedMorph
		portName: aSymbol! !

!DuinoBotPlayer methodsFor: 'sensor types' stamp: 'Richo 4/25/2011 17:16'!
setSensor0Tipo: aSymbol
	self costume renderedMorph sensor0Type: aSymbol! !

!DuinoBotPlayer methodsFor: 'sensor types' stamp: 'Richo 4/25/2011 17:16'!
setSensor1Tipo: aSymbol
	self costume renderedMorph sensor1Type: aSymbol! !

!DuinoBotPlayer methodsFor: 'sensor types' stamp: 'Richo 4/25/2011 17:16'!
setSensor2Tipo: aSymbol
	self costume renderedMorph sensor2Type: aSymbol! !

!DuinoBotPlayer methodsFor: 'sensor types' stamp: 'Richo 4/25/2011 17:16'!
setSensor3Tipo: aSymbol
	self costume renderedMorph sensor3Type: aSymbol! !

!DuinoBotPlayer methodsFor: 'sensor types' stamp: 'Richo 4/25/2011 17:16'!
setSensor4Tipo: aSymbol
	self costume renderedMorph sensor4Type: aSymbol! !

!DuinoBotPlayer methodsFor: 'sensor types' stamp: 'Richo 6/10/2011 16:34'!
setSensor5Tipo: aSymbol
	self costume renderedMorph sensor5Type: aSymbol! !
